/******************************************************************************
* Copyright (C) 2021 Xilinx, Inc.  All rights reserved.
* Copyright (C) 2022 - 2025 Advanced Micro Devices, Inc.  All rights reserved.
* SPDX-License-Identifier: MIT
******************************************************************************/
#ifndef _XPM_CONFIG_H
#define _XPM_CONFIG_H

#define XPAR_XILPM_ENABLED	 
/* #undef XCVP1902 */
/* #undef RAIL_CONTROL */
/* #undef VERSAL_DVS */
#define XCVR1602  
/* #undef XCVR1652 */
/* #undef ENABLE_BULK_DEV_RELEASE_SUPPORT */
/* #undef ENABLE_UNREGISTER_ALL_NOTIFIER_SUPPORT */

#endif /* XPM_CONFIG_H */
